Class: Atom::Element

Inherits:
Object
  • Object
show all
Defined in:
lib/sword2ruby/element.rb

Overview

Extensions to the atom-tools Atom::Element class to support Sword2 operations. These methods are additive to those supplied by the atom-tools gem.

Please see the atom-tools documentation for a complete list of attributes and methods.

Direct Known Subclasses

Collection, Entry, Feed, Service

Instance Attribute Summary collapse

Instance Attribute Details

#httpObject

Sword2Ruby::Connection (Atom::HTTP) object to facilitate connections in derived classes, such as Atom::Entry, Atom::Feed, Atom::Workspace and Atom::Collection.



10
11
12
# File 'lib/sword2ruby/element.rb', line 10

def http
  @http
end